<?php
namespace Teknisa\SM\Factory;

use Doctrine\ORM\EntityManager;

class ger00045000ProspectFactory
{
    
    protected $connection;
    
    public function __construct(EntityManager $entityManager) {
        
        $this->connection       = $entityManager->getConnection();
    }
    
    /**
     * Busca o número do parceiro de negócio do usuário logado
    **/
    public function getNrParcNegocio(array $params){
        $sql = "SELECT NRPARCNEGOCIO
                FROM OPERADOR 
                WHERE CDOPERADOR = :CDOPERADOR
                    AND NRORG    = :NRORG";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    public function insertProspectEvolNextTask($paramsInsertProspectEvolNextTask){

        $insert = "INSERT INTO FILACONTATO (DSFILACONTATO,DTPLANFILACONTA,CDOPERREAL,NRSEQFILACONTA,NRORG,DTINCLUSAO,NRORGINCLUSAO,
                               CDOPERINCLUSAO,NRPARCNEGOCIO,IDORIGFILACONTA,IDATIVO,NRCONTATO,NRSEQCONTATO, NRSEQINTERLOCUTOR, DSEMAILTAREFA, DSTELEFONETAREFA)
                    VALUES (:DSFILACONTATO,
                            :DTPLANFILACONTA,
                            :CDOPERREAL,
                            :NRSEQFILACONTA,
                            :NRORG,
                             SYSDATE,
                            :NRORGINCLUSAO,
                            :CDOPERINCLUSAO,
                            :NRPARCNEGOCIO,
                             'M',
                             'S',
                            :NRCONTATO,
                            :NRSEQCONTATO,
                            :NRSEQINTERLOCUTOR,
                            :DSEMAILTAREFA,
                            :DSTELEFONETAREFA)";
                 
        try{
            $std = $this->connection->prepare($insert);
            $std->execute($paramsInsertProspectEvolNextTask);
        }
        catch(\Exception $e){
            throw $e;
        };
    }
    
    public function verificaTarefas($paramsVerificaTarefas){
        $select = "SELECT FC.NRSEQFILACONTA, FC.CDOPERREAL
                     FROM FILACONTATO FC
                        LEFT JOIN PARCNEGOCIO PN
                         ON PN.NRPARCNEGOCIO = FC.NRPARCNEGOCIO
                          AND PN.NRORG = PN.NRORG
                    WHERE FC.NRPARCNEGOCIO = :NRPARCNEGOCIO
                      AND FC.NRORG = :NRORG 
                      AND FC.DTREALFILACONTA IS NULL
                      AND FC.IDATIVO = 'S' 
                      AND PN.IDATIVO = 'S'
                    ";
                      
        try{
            $std = $this->connection->prepare($select);
            $std->execute($paramsVerificaTarefas);
            $tarefas = $std->fetchAll();
            return $tarefas;
        }
        catch(\Exception $e){
            throw $e;
        };
    }
    
    public function selectProspectContact($paramsSelectProspectContact){
        $select = "SELECT NRSEQCONTATO
                     FROM CONTATO
                    WHERE NRPARCNEGOCIO = :NRPARCNEGOCIO
                      AND NRORG = :NRORG
                      AND UPPER(DSREFECONT) LIKE '%REFERENTE AO LEAD%'";
                      
        try{
            $std = $this->connection->prepare($select);
            $std->execute($paramsSelectProspectContact);
            $nrseqcontato = $std->fetchAll();
            return $nrseqcontato;
        }
        catch(\Exception $e){
            throw $e;
        };
    }
    
    public function requestForInsertNrseqcontatoForNewOpportunity($paramsUpdateOpportunity){
        
        $update = "UPDATE CRM_OPORTUNI 
                      SET NRSEQCONTATO = :NRSEQCONTATO,
                          NRCONTATO    = :NRSEQCONTATO    
                    WHERE NRSEQOPORT = :NRSEQOPORT";
        
        try{
            $std = $this->connection->prepare($update);
            $std->execute($paramsUpdateOpportunity);
        }
        catch(\Exception $e){
            throw $e;
        }; 
    }
    
    public function requestForUpdatePartnerType($paramsUpdatePartnerType){
        
        $update = "UPDATE PARCNEGOCIO
                      SET CDTIPOPARCPRINCIPAL = 'CLIENTE'
                    WHERE NRPARCNEGOCIO = :NRPARCNEGOCIO";
                    
        try{
            $std = $this->connection->prepare($update);
            $std->execute($paramsUpdatePartnerType);
        }
        catch(\Exception $e){
            throw $e;
        }; 
        
    }
    
    public function requestForInsertPartnershipOfTypeClient($paramsInsertPartnership){
        
        $insert = "INSERT INTO PARCERIA
                        (NRPARCERIA, NRPARCNEGOCIO, CDTIPOPARCEIRO, NRORG, IDATIVO, DTINCLUSAO,
                            NRORGINCLUSAO, CDOPERINCLUSAO)
                    VALUES(
                        :NRPARCERIA,
                        :NRPARCNEGOCIO,
                         'CLIENTE',
                        :NRORG,
                         'S',
                         SYSDATE,
                        :NRORGINCLUSAO,
                        :CDOPERINCLUSAO
                    )";
    
        try{
            $std = $this->connection->prepare($insert);
            $std->execute($paramsInsertPartnership);
        }
        catch(\Exception $e){
            throw $e;
        }; 
        
    }
    
    public function requestForInsertClient($paramsInsertClient){
        
        $insert = "INSERT INTO CLIENTE 
                        (CDCLIENTE, NRPARCNEGOCIO, IDTPIJURCLIE, NRINSJURCLIE, NMRAZSOCCLIE, NMFANTCLIE,
                            NRORG, NRORGINCLUSAO, CDOPERINCLUSAO, DTINCLUSAO)
                    VALUES(
                    
                        :CDCLIENTE,
                        :NRPARCNEGOCIO,
                        :IDTPIJURCLIE,
                        :NRINSJURCLIE,
                        :NMRAZSOCCLIE,
                        :NMFANTCLIE,
                        :NRORG,
                        :NRORGINCLUSAO,
                        :CDOPERINCLUSAO,
                         SYSDATE
                    )";
        
        try{
            $std = $this->connection->prepare($insert);
            $std->execute($paramsInsertClient);
        }
        catch(\Exception $e){
            throw $e;
        };
        
    }
    
    public function requestForDeactivateProspect($paramsUpdateProspect){
        
        $update = "UPDATE PROSPECT
                      SET IDATIVO = 'N'
                    WHERE CDPROSPECT = :CDPROSPECT";
        
        try{
            $std = $this->connection->prepare($update);
            $std->execute($paramsUpdateProspect);
        }
        catch(\Exception $e){
            throw $e;
        };
    }
    
    public function requestForInsertClientAddress($paramsInsertClientAddress){
        $insert = "INSERT INTO ENDECLIE (CDCLIENTE, IDTPENDECLIE, CDPAIS, SGESTADO, CDMUNICIPIO, CDBAIRRO, DSENDECLIE, 
                      NMBAIRCLIE, DSCOMPENDCLI, NRCEPCLIE, NRTELECLIE, NRRAMALCLIE ,DSEMAILCLIE, NRENDERECOPARC, 
                      NRORG, DTINCLUSAO, NRORGINCLUSAO, CDOPERINCLUSAO, IDATIVO)
              VALUES (
                :CDCLIENTE,
                :IDTPENDECLIE,
                :CDPAIS,
                :SGESTADO,
                :CDMUNICIPIO,
                :CDBAIRRO,
                :DSENDECLIE,
                :NMBAIRCLIE,
                :DSCOMPENDCLI,
                :NRCEPCLIE,
                :NRTELECLIE,
                :NRRAMALCLIE,
                :DSEMAILCLIE,
                :NRENDERECOPARC, 
                :NRORG,
                SYSDATE,
                :NRORGINCLUSAO,
                :CDOPERINCLUSAO,
                'S'
              )";
        
        try{
            $std = $this->connection->prepare($insert);
            $std->execute($paramsInsertClientAddress);
        }
        catch(\Exception $e){
            throw $e;
        };
    }
    
    public function requestForSelectProspectAddress($paramsSelectProspectAddress){
        
        $select = "SELECT IDTPENDEPROS, CDPAIS, SGESTADO, CDMUNICIPIO, CDBAIRRO, DSENDEPROS,
                NMBAIRPROS, DSCOMPENDPRO, NRCEPPROS, NRTELEPROS, NRRAMALPROS, DSEMAILPROS, NRENDERECOPARC
                FROM ENDEPROSPECT
                    WHERE CDPROSPECT = :CDPROSPECT
                        AND NRORG = :NRORG
                        AND CDPAIS IS NOT NULL
                        AND SGESTADO IS NOT NULL
                        AND CDMUNICIPIO IS NOT NULL";
        
        try{
            $std = $this->connection->prepare($select);
            $std->execute($paramsSelectProspectAddress);
            return $std->fetchAll();
        }
        catch(\Exception $e){
            throw $e;
        };
        
    }
    
     public function getOperador($paramsSelectOperador){
        
        $select = "SELECT INITCAP(NMOPERADOR) NMOPERADOR FROM OPERADOR
                        WHERE CDOPERADOR = :CDOPERREAL
                            AND NRORG = :NRORG";
        
        try{
            $std = $this->connection->prepare($select);
            $std->execute($paramsSelectOperador);
            return $std->fetchAll();
        }
        catch(\Exception $e){
            throw $e;
        };
        
    }
    
    public function getParceiro($paramsSelectOperador){
        
        $select = "SELECT INITCAP(NMPRINCIPALPARC) NMPRINCIPALPARC FROM PARCNEGOCIO
                        WHERE NRPARCNEGOCIO = :NRPARCNEGOCIO
                            AND NRORG = :NRORG";
        
        try{
            $std = $this->connection->prepare($select);
            $std->execute($paramsSelectOperador);
            return $std->fetchAll();
        }
        catch(\Exception $e){
            throw $e;
        };
        
    }
    
    public function requestForSetTaskEndDate($paramsSetTaskEndDate){
        
        $update = "UPDATE FILACONTATO 
                   SET DTREALFILACONTA = SYSDATE
                   WHERE NRSEQFILACONTA = :NRSEQFILACONTA";
        
        try{
            $std = $this->connection->prepare($update);
            $std->execute($paramsSetTaskEndDate);
        }
        catch(\Exception $e){
            throw $e;
        };
        
    }
    
    public function requestForDeactivateProspectTask($taskUpdateParams){
        
        $update = "UPDATE FILACONTATO
                   SET IDATIVO = 'N'
                   WHERE NRSEQFILACONTA = :NRSEQFILACONTA";
                   
        try{
            
            $std = $this->connection->prepare($update);
            $std->execute($taskUpdateParams);
            
        }catch(\Exception $e){
            
            throw $e;
            
        }
        
    }
    
     public function getInterlocutorParc($nrrelacionaparc, $nrorg){
            
        $selectInterlocutorParc = "SELECT NRPARCNEGRELAC
                                        FROM RELACIONAPARC
                                        WHERE NRRELACIONAPARC = '$nrrelacionaparc'
                                        AND NRORG = '$nrorg' " ;
        
        
        try{
            $std = $this->connection->prepare($selectInterlocutorParc);
            $std->execute();
            $nrparcnegocio = $std->fetchAll();
            
        }catch(\Exception $e){
            
            throw $e;
            
        }
        if(isset($nrparcnegocio[0]))
            return $nrparcnegocio[0]['NRPARCNEGRELAC'];
        
    }
    
    public function getEnderecoparcInterlocutor($nrparcnegocioInterlocutor, $nrorg){
            
        $selectInterlocutorParc = "SELECT NRENDERECOPARC
                                        FROM ENDERECOPARC
                                        WHERE NRPARCNEGOCIO = '$nrparcnegocioInterlocutor'
                                        AND NRORG = '$nrorg' " ;

        
        try{
            $std = $this->connection->prepare($selectInterlocutorParc);
            $std->execute();
            $nrenderecoparcInterlocutor = $std->fetchAll();
            
        }catch(\Exception $e){
            
            throw $e;
            
        }
        if(isset($nrenderecoparcInterlocutor[0]))
            return $nrenderecoparcInterlocutor[0]['NRENDERECOPARC'];
        else
            return false;
        
    }
    
    public function replicaEnderecoparcInterlocutor($paramsUpdateEndeparc){
            
        $update = "UPDATE ENDERECOPARC SET CDTIPOENDERECO = :CDTIPOENDERECO,
                        DTULTATU = SYSDATE, NRORGULTATU = :NRORGULTATU, CDOPERULTATU = :CDOPERULTATU, CDPAIS = :CDPAIS, SGESTADO = :SGESTADO, CDMUNICIPIO = :CDMUNICIPIO, CDBAIRRO = :CDBAIRRO, NMBAIRROENDERECO = :NMBAIRROENDERECO,
                       DSENDERECO = :DSENDERECO,  NRCEPENDERECO = :NRCEPENDERECO
                    WHERE NRPARCNEGOCIO = :NRPARCNEGOCIO AND NRENDERECOPARC = :NRENDERECOPARC AND NRORG = :NRORG";
        try{
            $std = $this->connection->prepare($update);
            $std->execute($paramsUpdateEndeparc);
        }
        catch(\Exception $e){
            throw $e;
        };
        
    }
    
    public function insertEnderecoparc($paramsInsertEndeparc){

        $insert = "INSERT INTO ENDERECOPARC (IDATIVO, NRPARCNEGOCIO, NRORG, NRENDERECOPARC, CDTIPOENDERECO,
                        DTINCLUSAO, NRORGINCLUSAO, CDOPERINCLUSAO, CDPAIS, SGESTADO, CDMUNICIPIO, CDBAIRRO, NMBAIRROENDERECO, DSCOMPLEENDERECO,
                        NRCEPENDERECO, DSENDERECO, NRIMOVELENDERECO)
         VALUES (:IDATIVO,
                 :NRPARCNEGOCIO,
                 :NRORG,
                 :NRENDERECOPARC,
                 :CDTIPOENDERECO,
                  SYSDATE,
                 :NRORGINCLUSAO,
                 :CDOPERINCLUSAO,
                 :CDPAIS,
                 :SGESTADO,
                 :CDMUNICIPIO,
                 :CDBAIRRO,
                 :NMBAIRROENDERECO,
                 :DSENDERECO,
                 :NRCEPENDERECO,
                 :DSCOMPLEENDERECO,
                 :NRIMOVELENDERECO
                )";
                 
        try{
            $std = $this->connection->prepare($insert);
            $std->execute($paramsInsertEndeparc);
        }
        catch(\Exception $e){
            throw $e;
        };
        
    }
    
    public function setIdQualificadoProspect($paramsSetQualification){
        
        $update = "UPDATE PROSPECT 
                      SET IDQUALIFICADO = :IDQUALIFICADO    
                    WHERE CDPROSPECT = :CDPROSPECT
                        AND NRORG = :NRORG";
        
        try{
            $std = $this->connection->prepare($update);
            $std->execute($paramsSetQualification);
        }
        catch(\Exception $e){
            throw $e;
        }; 
    }
    
    public function insertConcorrProspect($paramsInsertConcorrProspect){
        
        $insert = "INSERT INTO CRM_CONCORRPROSPECT
                        (NRCONCORRPROSPECT, CDPROSPECT, NRCONCORRENTE, NRORG, DTINIVIGENCIA, DTFIMVIGENCIA,
                            DTINCLUSAO, DTULTATU, NRORGINCLUSAO, NRORGULTATU, CDOPERINCLUSAO, CDOPERULTATU)
                    VALUES(
                        :NRCONCORRPROSPECT,
                        :CDPROSPECT,
                        :NRCONCORRENTE,
                        :NRORG,
                        :DTINIVIGENCIA,
                        :DTFIMVIGENCIA,
                         SYSDATE,
                         SYSDATE,
                        :NRORG,
                        :NRORG,
                        :CDOPERINCLUSAO,
                        :CDOPERINCLUSAO
                    )";
    
        try{
            $std = $this->connection->prepare($insert);
            $std->execute($paramsInsertConcorrProspect);
        }
        catch(\Exception $e){
            throw $e;
        }; 
        
    }
    
    public function updateConcorrProspect($paramsSetConcorr){
        
        $update = "UPDATE CRM_CONCORRPROSPECT 
                      SET DTINIVIGENCIA = :DTINIVIGENCIA,
                          DTFIMVIGENCIA = :DTFIMVIGENCIA,
                          NRCONCORRENTE = :NRCONCORRENTE
                    WHERE NRCONCORRPROSPECT = :NRCONCORRPROSPECT
                        AND NRORG = :NRORG";
        
        try{
            $std = $this->connection->prepare($update);
            $std->execute($paramsSetConcorr);
        }
        catch(\Exception $e){
            throw $e;
        }; 
    }
    
    public function deleteConcorrProspect($paramsDeleteConcorr){
        
        $delete = "DELETE FROM CRM_CONCORRPROSPECT 
                    WHERE NRCONCORRPROSPECT = :NRCONCORRPROSPECT
                        AND NRORG = :NRORG";
        
        try{
            $std = $this->connection->prepare($delete);
            $std->execute($paramsDeleteConcorr);
        }
        catch(\Exception $e){
            throw $e;
        }; 
    }
    
    public function validaCNPJCliente($paramsSelectClient){
        $select = "SELECT NMRAZSOCCLIE
                     FROM CLIENTE
                    WHERE NRINSJURCLIE = :CNPJ
                      AND NRORG = :NRORG" ;
                      
        try{
            $std = $this->connection->prepare($select);
            $std->execute($paramsSelectClient);
            return $std->fetchAll();
        }
        catch(\Exception $e){
            throw $e;
        };
    }
    
    public function createPartnership($params){
        $queryInsertParceria = "INSERT INTO PARCERIA(NRPARCERIA, NRORG, NRPARCNEGOCIO, CDTIPOPARCEIRO, IDATIVO, DTINCLUSAO, CDOPERINCLUSAO, NRORGINCLUSAO)
        VALUES(:NRPARCERIA, :NRORG, :NRPARCNEGOCIO, :CDTIPOPARCEIRO, :IDATIVO, SYSDATE, :CDOPERINCLUSAO, :NRORGINCLUSAO)";
                      
        try{
            $std = $this->connection->prepare($queryInsertParceria);
            $std->execute($params);
        }
        catch(\Exception $e){
            throw $e;
        };
    }
    
    public function setParceiroNegocio($params){
        $insert = "INSERT INTO PARCNEGOCIO (NRPARCNEGOCIO, NRORG, NMPRINCIPALPARC, NMSECUNDARIPARC, NRINSCRICAOPARC, IDATIVO, DTINCLUSAO,
                         NRORGINCLUSAO, CDOPERINCLUSAO, CDTIPOPARCPRINCIPAL, CDTIPOINSCRICAO,IDPESSOAFISICA)
                 VALUES (:NRPARCNEGOCIO,
                         :NRORG,
                         :NMPRINCIPALPARC,
                         :NMSECUNDARIPARC,
                         :NRINSCRICAOPARC,
                         :IDATIVO,
                          SYSDATE,
                         :NRORGINCLUSAO,
                         :CDOPERINCLUSAO,
                         :CDTIPOPARCPRINCIPAL,
                         :CDTIPOINSCRICAO,
                         :IDPESSOAFISICA)";             
        try{
            $std = $this->connection->prepare($insert);
            $std->execute($params);
        }
        catch(\Exception $e){
            throw $e;
        };
    }
    
    public function newContato($params){
        $query = "INSERT INTO CONTATO (CDPROSPECT, CDCLIENTE, CDFORNECED, DSREFECONT, IDSTATUSCONT, IDTPCONTATO, CDOPERCONT, NRORG, NRPARCNEGOCIO, IDATIVO, CDFILIAL, NRCONTATO, NRSEQCONTATO, DTHRCONTATO, DTINCLUSAO, NRORGINCLUSAO, CDOPERINCLUSAO)
            SELECT PROS.CDPROSPECT, CLIE.CDCLIENTE, FORN.CDFORNECED, :DSREFECONT, :IDSTATUSCONT, :IDTPCONTATO, :CDOPERCONT, :NRORG, :NRPARCNEGOCIO, 'S' AS IDATIVO, :CDFILIAL, :NRCONTATO, :NRSEQCONTATO, SYSDATE AS DTHRCONTATO, SYSDATE AS DTINCLUSAO, :NRORG AS NRORGINCLUSAO, :CDOPERCONT
            FROM PARCNEGOCIO PARC LEFT JOIN PROSPECT PROS
            ON PARC.NRPARCNEGOCIO = PROS.NRPARCNEGOCIO AND PARC.IDATIVO = PROS.IDATIVO AND PARC.NRORG = PROS.NRORG
            LEFT JOIN CLIENTE CLIE
            ON PARC.NRPARCNEGOCIO = CLIE.NRPARCNEGOCIO AND PARC.IDATIVO = CLIE.IDATIVO AND PARC.NRORG = CLIE.NRORG
            LEFT JOIN FORNECEDOR FORN
            ON PARC.NRPARCNEGOCIO = FORN.NRPARCNEGOCIO AND PARC.IDATIVO = FORN.IDATIVO AND PARC.NRORG = FORN.NRORG
            WHERE PARC.NRPARCNEGOCIO = :NRPARCNEGOCIO AND PARC.NRORG = :NRORG AND PARC.IDATIVO = 'S'";        
        try{
            $std = $this->connection->prepare($query);
            $std->execute($params);
        }
        catch(\Exception $e){
            throw $e;
        };
    }
    
    public function verifyLeadInsc($paramsVerifyLeadCPNJ, $tabela, $fieldInscricao, $fieldNome){
        $select = "SELECT CASE WHEN NMOPERADOR IS NOT NULL THEN '<b>' || {$fieldNome} || ' - ' || NMOPERADOR || '</b>'
                        ELSE '<b>' || {$fieldNome} || '</b>'
                        END AS {$fieldNome}
                    FROM {$tabela} 
                    LEFT JOIN PROSPECT 
                        ON {$tabela}.NRPARCNEGOCIO = PROSPECT.NRPARCNEGOCIO
                        AND {$tabela}.NRORG        = PROSPECT.NRORG
                    LEFT JOIN OPERADOR 
                        ON (({$tabela}.CDOPERRESPONSAVEL IS NULL
                                AND PROSPECT.NRPARCRESPROSP  = OPERADOR.NRPARCNEGOCIO)
                            OR {$tabela}.CDOPERRESPONSAVEL = OPERADOR.CDOPERADOR)
                    WHERE {$fieldInscricao} = :INSCRICAO
                      AND {$tabela}.NRORG = :NRORG
                      AND {$tabela}.IDATIVO = 'S' ";
                      
        try{
            $std = $this->connection->prepare($select);
            $std->execute($paramsVerifyLeadCPNJ);
            $leads = $std->fetchAll();
            return $leads;
        }
        catch(\Exception $e){
            throw $e;
        };
    }
    
    public function verifyLeadCNPJ($paramsVerifyLeadCPNJ, $tabela, $fieldInscricao, $fieldNome){
        $select = "SELECT CASE WHEN NMOPERADOR IS NOT NULL THEN '<b>' || {$fieldNome} || ' - ' || NMOPERADOR || '</b>'
                        ELSE '<b>' || {$fieldNome} || '</b>'
                        END AS {$fieldNome}
                    FROM {$tabela} 
                    LEFT JOIN PROSPECT 
                        ON {$tabela}.NRPARCNEGOCIO = PROSPECT.NRPARCNEGOCIO
                        AND {$tabela}.NRORG        = PROSPECT.NRORG
                    LEFT JOIN OPERADOR 
                        ON (({$tabela}.CDOPERRESPONSAVEL IS NULL
                                AND PROSPECT.NRPARCRESPROSP  = OPERADOR.NRPARCNEGOCIO)
                            OR {$tabela}.CDOPERRESPONSAVEL = OPERADOR.CDOPERADOR)
                    WHERE {$fieldInscricao} LIKE('%'|| :INSCRICAO || '%')
                      AND {$tabela}.NRORG = :NRORG
                      AND {$tabela}.IDATIVO = 'S' ";
        try{
            $std = $this->connection->prepare($select);
            $std->execute($paramsVerifyLeadCPNJ);
            $leads = $std->fetchAll();
            return $leads;
        }
        catch(\Exception $e){
            throw $e;
        };
    }
    
    public function verifyLeadName($paramsVerifyLeadName, $tabela, $fieldNome){
        $select = "SELECT {$fieldNome}
                     FROM {$tabela}
                    WHERE UPPER({$fieldNome}) LIKE('%'|| :NOME || '%')
                      AND NRORG = :NRORG
                      AND IDATIVO = 'S' ";
                      
        try{
            $std = $this->connection->prepare($select);
            $std->execute($paramsVerifyLeadName);
            $leads = $std->fetchAll();
            return $leads;
        }
        catch(\Exception $e){
            throw $e;
        };
    }
    

    public function insereEnderecoProspect($params){
        
        $query = "INSERT INTO ENDERECOPARC (NRENDERECOPARC, NRPARCNEGOCIO, CDTIPOENDERECO, NRORG, IDATIVO, DTINCLUSAO,
                                            NRORGINCLUSAO, CDOPERINCLUSAO, CDPAIS, SGESTADO, CDMUNICIPIO, CDBAIRRO,
                                            NMBAIRROENDERECO, DSCOMPLEENDERECO, NRCEPENDERECO, DSENDERECO, 
                                            NRIMOVELENDERECO, DSREFERENCIAENDE)
                           VALUES(:NRENDERECOPARC, :NRPARCNEGOCIO, :CDTIPOENDERECO, :NRORG, :IDATIVO, :DTINCLUSAO,
                                  :NRORGINCLUSAO, :CDOPERINCLUSAO, :CDPAIS, :SGESTADO, :CDMUNICIPIO, :CDBAIRRO, 
                                  :NMBAIRROENDERECO, :DSCOMPLEENDERECO, :NRCEPENDERECO, :DSENDERECO,
                                  :NRIMOVELENDERECO, :DSREFERENCIAENDE)";

        $std = $this->connection->prepare($query);
        $std->execute($params);
    }
    
    public function editaEnderecoProspect($params){
        
        $query = "UPDATE ENDERECOPARC
                     SET CDTIPOENDERECO = :CDTIPOENDERECO,
                         CDPAIS = :CDPAIS,
                         SGESTADO = :SGESTADO,
                         CDMUNICIPIO = :CDMUNICIPIO,
                         CDBAIRRO = :CDBAIRRO,
                         NMBAIRROENDERECO = :NMBAIRROENDERECO,
                         DSCOMPLEENDERECO = :DSCOMPLEENDERECO,
                         NRCEPENDERECO = :NRCEPENDERECO,
                         DSENDERECO = :DSENDERECO,
                         NRIMOVELENDERECO = :NRIMOVELENDERECO,
                         DSREFERENCIAENDE = :DSREFERENCIAENDE,
                         DTULTATU = SYSDATE,
                         NRORGULTATU = NRORG,
                         CDOPERULTATU = :OPERADOR
                     WHERE NRENDERECOPARC = :NRENDERECOPARC
                         AND NRPARCNEGOCIO = :NRPARCNEGOCIO
                         AND NRORG = :NRORG";

        $std = $this->connection->prepare($query);
        $std->execute($params);
    }
    
    public function insereInterlocutorProspect($params){
        
        $query = "INSERT INTO CRM_INTERLOCUTOR (NRSEQINTERLOCUTOR, NMINTERLOCUTOR, NRPARCNEGOCIO, EMAILINTERLOC, NRTELEFONE1, NRTELEFONE2, NRTELEFONE3,
                              NRTELEFONE4, CDCARGOINTERLOC, DTNASCIMENTO, IDRECEBEPRESENTE, CDPAIS, SGESTADO, CDMUNICIPIO, CDBAIRRO,
                              NRCEPINTERLOCUTOR, DSENDEINTERLOCUTOR, DSCOMPINTERLOCUTOR, NRENDEINTERLOCUTOR, NRORG, IDATIVO, DTINCLUSAO, 
                              NRORGINCLUSAO, CDOPERINCLUSAO, CDSETOR, NRCPFINTERLOC)
             VALUES(:NRSEQINTERLOCUTOR, :NMINTERLOCUTOR, :NRPARCNEGOCIO, :EMAILINTERLOC, :NRTELEFONE1, :NRTELEFONE2, :NRTELEFONE3,
                    :NRTELEFONE4, :CDCARGOINTERLOC, :DTNASCIMENTO, :IDRECEBEPRESENTE, :CDPAIS, :SGESTADO, :CDMUNICIPIO, :CDBAIRRO,
                    :NRCEPINTERLOCUTOR, :DSENDEINTERLOCUTOR, :DSCOMPINTERLOCUTOR, :NRENDEINTERLOCUTOR, :NRORG, :IDATIVO, :DTINCLUSAO,
                    :NRORGINCLUSAO, :CDOPERINCLUSAO, :CDSETOR, :NRCPFINTERLOC)";

        $std = $this->connection->prepare($query);
        $std->execute($params);
    }
    
    public function editaInterlocutorProspect($params){
        
        $query = "UPDATE CRM_INTERLOCUTOR
                     SET NMINTERLOCUTOR = :NMINTERLOCUTOR,
                         NRPARCNEGOCIO = :NRPARCNEGOCIO,
                         EMAILINTERLOC = :EMAILINTERLOC,
                         NRTELEFONE1 = :NRTELEFONE1,
                         NRTELEFONE2 = :NRTELEFONE2,
                         NRTELEFONE3 = :NRTELEFONE3,
                         NRTELEFONE4 = :NRTELEFONE4,
                         CDCARGOINTERLOC = :CDCARGOINTERLOC,
                         DTNASCIMENTO = :DTNASCIMENTO,
                         IDRECEBEPRESENTE = :IDRECEBEPRESENTE,
                         CDPAIS = :CDPAIS,
                         SGESTADO = :SGESTADO,
                         CDMUNICIPIO = :CDMUNICIPIO,
                         CDBAIRRO = :CDBAIRRO,
                         NRCEPINTERLOCUTOR = :NRCEPINTERLOCUTOR,
                         DSENDEINTERLOCUTOR = :DSENDEINTERLOCUTOR,
                         DSCOMPINTERLOCUTOR = :DSCOMPINTERLOCUTOR,
                         NRENDEINTERLOCUTOR = :NRENDEINTERLOCUTOR,
                         CDSETOR = :CDSETOR,
                         NRCPFINTERLOC = :NRCPFINTERLOC,
                         DTULTATU = SYSDATE,
                         NRORGULTATU = NRORG,
                         CDOPERULTATU = :OPERADOR
                  WHERE NRSEQINTERLOCUTOR = :NRSEQINTERLOCUTOR
                    AND NRPARCNEGOCIO = :NRPARCNEGOCIO
                    AND NRORG = :NRORG";

        $std = $this->connection->prepare($query);
        $std->execute($params);
    }
    
    public function inserecrmInterlocutor($params){
        
        $query = "INSERT INTO CRM_INTERLOCUTOR (NRSEQINTERLOCUTOR, NMINTERLOCUTOR, NRPARCNEGOCIO, EMAILINTERLOC, NRTELEFONE1,
                                NRORG, IDATIVO, DTINCLUSAO, NRORGINCLUSAO, CDOPERINCLUSAO)
                        VALUES (:NRSEQINTERLOCUTOR, :NMINTERLOCUTOR, :NRPARCNEGOCIO, :EMAILINTERLOC, :NRTELEFONE1,
                                :NRORG, :IDATIVO, SYSDATE, :NRORGINCLUSAO, :CDOPERINCLUSAO)";

        $std = $this->connection->prepare($query);
        $std->execute($params);
    }
    
    public function insereInteProsp($params){
        
        $query = "INSERT INTO INTEPROSP (CDINTEPROS, CDPROSPECT, NMINTEPROS, DSEMAILIPROS, NRTEL1INPROS,
                                NRORG, IDATIVO, DTINCLUSAO, NRORGINCLUSAO, CDOPERINCLUSAO, IDTPINTEPROS)
                        VALUES (:CDINTEPROS, :CDPROSPECT, :NMINTEPROS, :DSEMAILIPROS, :NRTEL1INPROS,
                                :NRORG, :IDATIVO, SYSDATE, :NRORGINCLUSAO, :CDOPERINCLUSAO, :IDTPINTEPROS)";

        $std = $this->connection->prepare($query);
        $std->execute($params);
    }
    
    public function insereEnderecoParc($params){
        
        $query = "INSERT INTO ENDERECOPARC (NRENDERECOPARC, NRPARCNEGOCIO, CDTIPOENDERECO, NRORG, IDATIVO, DTINCLUSAO,
                                            NRORGINCLUSAO, CDOPERINCLUSAO, NRCEPENDERECO, DSENDERECO, NRIMOVELENDERECO,
                                            DSCOMPLEENDERECO, CDPAIS, SGESTADO, CDMUNICIPIO, CDBAIRRO, NMBAIRROENDERECO)
                           VALUES(:NRENDERECOPARC, :NRPARCNEGOCIO, :CDTIPOENDERECO, :NRORG, :IDATIVO, SYSDATE,
                                  :NRORGINCLUSAO, :CDOPERINCLUSAO, :NRCEPENDERECO, :DSENDERECO, :NRIMOVELENDERECO,
                                  :DSCOMPLEENDERECO, :CDPAIS, :SGESTADO, :CDMUNICIPIO, :CDBAIRRO, :NMBAIRROENDERECO)";

        $std = $this->connection->prepare($query);
        $std->execute($params);
    }
    
    /**
     * Efetua a alteração dos operadores responsáveis de determinados prospects 
    **/
    public function salvarAlteracoesOpersResp($prospects, array $params){
        $sql = "UPDATE PROSPECT
                SET NRPARCRESPROSP = :NRPARCRESPROSP
                WHERE NRORG = :NRORG
                    AND CDPROSPECT IN ('".$prospects."')";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    /**
     * Aplica a mesma alteração do operador responsável do prospect 
     * no parceiro de negocio
    **/
    public function salvarAlteracoesOpersRespParc($prospects, array $params){
        $sql = "UPDATE PARCNEGOCIO
                SET CDOPERRESPONSAVEL = (SELECT CDOPERADOR 
                                                FROM OPERADOR 
                                                WHERE NRPARCNEGOCIO = :NRPARCRESPROSP)
                WHERE NRPARCNEGOCIO IN(SELECT NRPARCNEGOCIO 
                                        FROM PROSPECT 
                                        WHERE CDPROSPECT IN('".$prospects."'))
                    AND NRORG = :NRORG";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    /**
     * Seleciona na tabela de operador o codigo correspondente ao parceiro
     * responsavel pelo prospect 
    **/
    public function getCdOperadorResponsavel($nrorg, $prospect){
        $sql = "SELECT PROSPECT.NRPARCNEGOCIO, CDOPERADOR
                FROM PROSPECT 
                LEFT JOIN OPERADOR 
                  ON PROSPECT.NRPARCRESPROSP = OPERADOR.NRPARCNEGOCIO
                  AND PROSPECT.NRORG         = OPERADOR.NRORG 
                WHERE PROSPECT.CDPROSPECT IN('$prospect')
                    AND PROSPECT.NRORG = $nrorg";
        $std = $this->connection->prepare($sql);
        $std->execute();
        return $std->fetchAll();
    }
    
    /**
     * Seleciona o código do novo operador responsavel pelo prospect
    **/
    public function getCdNewOperadorResponsavel(array $params){
        $sql = "SELECT CDOPERADOR
                FROM OPERADOR 
                WHERE NRPARCNEGOCIO = :NRPARCRESPROSP
                    AND NRORG = :NRORG";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        $result = $std->fetchAll();
        return (count($result) > 0) ? $result[0]["CDOPERADOR"] : null;
    }
    
     /**
     * A função "buscaFilialHierarquia" busca a filial vinculado ao operador 
     * na hierarquiia de operadores (CRM_HIERARQUIAOPER)
     */
     
    public function buscaFilialHierarquia(array $params) {
        $sql = "SELECT CRM_HIERARQUIAOPER.CDFILIAL, FILIAL.NMFILIAL
                  FROM CRM_HIERARQUIAOPER
                  JOIN FILIAL 
                    ON FILIAL.CDFILIAL = CRM_HIERARQUIAOPER.CDFILIAL
                   AND FILIAL.NRORG = CRM_HIERARQUIAOPER.NRORG
                  WHERE CRM_HIERARQUIAOPER.CDOPERADOR = :CDOPERADOR
                    AND CRM_HIERARQUIAOPER.NRORG = :NRORG
                    AND ROWNUM = 1
                ORDER BY CRM_HIERARQUIAOPER.DTULTATU DESC";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
}
?>